package com.example.checkboxhobbies_3_f21

/*
    A bunch of checkboxes are generated dynamically based
    on a resource array of hobbies.

    Those checkboxes are arranged into three columns achieved
    by using three LinearLayouts that are vertically oriented
    which are all inside a horizontally-oriented linearLayout

    The checkbox event handler adds or removes hobbies from
    a list displayed in a Textview at the bottom
*/

import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import android.widget.*
import androidx.core.view.children

class MainActivity : AppCompatActivity() {

    val cb_id_base:Int = 5000
    // we will assign the dynamic checkboxes ids starting with this number
    val user_hobbies = mutableListOf<String>()
    // the hobbies the user checks

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_main)

        // there is an array of possible hobbies in res/values/strings.xml
        val hobbies = resources.getStringArray(R.array.hobbies)

        // there is a horizontal layout with children that are (initially empty) vertical linear layouts
        val ll_hobbies = findViewById<LinearLayout>(R.id.ll_hobby)
        //val cols = ll_hobbies.children
        val col_num = ll_hobbies.childCount

        // loop over hobbies array add checkboxes to vertical linearLayout that are the
        // (three) columns in the horizontal (hobby) LinearLayout
        for (i in 0 until hobbies.size) {
            //Toast.makeText(this,item,Toast.LENGTH_SHORT).show()
            val cbHobby = CheckBox(this)  //instantiate a Checkbox
            cbHobby.setText(hobbies[i])                 //set the Text property
            cbHobby.id= cb_id_base+i
            val current_column = ll_hobbies.getChildAt(i%col_num) as LinearLayout
            current_column?.addView(cbHobby)          //add dynamic Checkbox
            cbHobby.setOnCheckedChangeListener(myCheckBoxListener)
        }

    }//end onCreate

    //***************************************************************************************************************
    //checkbox checked change listener -- though we have to use CompoundButton
    var myCheckBoxListener: CompoundButton.OnCheckedChangeListener =
        CompoundButton.OnCheckedChangeListener { buttonView, isChecked ->

            val tvHobbies = findViewById<TextView>(R.id.txtHobby)

            if(isChecked){
                //add to user hobbies
                user_hobbies.add(buttonView.text.toString())
            }else{
                //remove from user hobbies
                user_hobbies.remove(buttonView.text.toString())
            }
            tvHobbies.text = user_hobbies.joinToString(", ")

        }//end myCheckBoxListener

}//end mainActivity class